==> gitlab_dart-0.1.0.tar.gz: lib/src/api/base.dart <==
import 'dart:convert';

import 'package:gitlab_dart/gitlab_dart.dart';
import 'package:http/http.dart' as http;

mixin BaseAPI {
  String _APIURL;
  Token authToken;

  void set APIURL(String url) => this._APIURL =
      url[url.length - 1] == "/" ? url.substring(0, url.length - 1) : url;

  String get APIURL => this._APIURL;

  String generateParams(Map<String, dynamic> params) {
    if (params == null || params.isEmpty) {
      return '';
    } else {
      List<String> paramStrings = [];
      params.forEach((key, val) => paramStrings.add("$key=$val"));
      return paramStrings.join("&");
    }
  }

  String generateURL(String url, {Map<String, dynamic> params}) {
    var paramsString = (params != null && params?.isNotEmpty)
        ? this.generateParams(params)
        : null;
    String rurl =
        "${this.APIURL}$url${(paramsString != null) ? '?${paramsString}' : ''}";
    return rurl;
  }

  Map<String, String> getHeader(
      {bool auth = true, Map<String, String> addHeaders}) {
    Map<String, String> headers = addHeaders != null ? addHeaders : {};
    if (auth) {
      if (this.authToken != null) {
        if (this.authToken.type == "Oauth2") {
          headers['Authorization'] = "Bearer ${this.authToken.token}";
        } else if (this.authToken.type == "personal") {
          headers['Private-Token'] = this.authToken.token;
        }
      }
    }
    return headers;
  }

  Future<Map<String, dynamic>> mapFromGet(String url,
      {Map<String, dynamic> params,
      bool auth = true,
      Map<String, String> addHeaders}) async {
    var client = http.Client();
    try {
      var headers = this.getHeader(auth: auth, addHeaders: addHeaders);
      var gurl = generateURL(url, params: params);
      var resp = await client.get(gurl, headers: headers);
      print(resp);
      return json.decode(utf8.decode(resp.bodyBytes));
    } catch (e) {
      throw e;
    }
  }

  Future<List<dynamic>> listFromGet(String url,
      {Map<String, dynamic> params,
      bool auth = true,
      Map<String, String> addHeaders}) async {
    var client = http.Client();
    try {
      var headers = this.getHeader(auth: auth, addHeaders: addHeaders);
      var resp =
          await client.get(generateURL(url, params: params), headers: headers);
      return json.decode(utf8.decode(resp.bodyBytes));
    } catch (e) {
      throw e;
    }
  }
}

==> gitlab_dart-0.1.1.tar.gz: lib/src/api/base.dart <==
import 'dart:convert';

import 'package:gitlab_dart/gitlab_dart.dart';
import 'package:http/http.dart' as http;

mixin BaseAPI {
  String _apiURL;
  Token authToken;

  set apiURL(String url) => this._apiURL =
      url[url.length - 1] == "/" ? url.substring(0, url.length - 1) : url;

  String get apiURL => this._apiURL;

  String generateParams(Map<String, dynamic> params) {
    if (params == null || params.isEmpty) {
      return '';
    } else {
      List<String> paramStrings = [];
      params.forEach((key, val) => paramStrings.add("$key=$val"));
      return paramStrings.join("&");
    }
  }

  String generateURL(String url, {Map<String, dynamic> params}) {
    var paramsString = (params != null && params.isNotEmpty)
        ? this.generateParams(params)
        : null;
    String rurl =
        "${this.apiURL}$url${(paramsString != null) ? '?${paramsString}' : ''}";
    return rurl;
  }

  Map<String, String> getHeader(
      {bool auth = true, Map<String, String> addHeaders}) {
    Map<String, String> headers = addHeaders != null ? addHeaders : {};
    if (auth) {
      if (this.authToken != null) {
        if (this.authToken.type == "Oauth2") {
          headers['Authorization'] = "Bearer ${this.authToken.token}";
        } else if (this.authToken.type == "personal") {
          headers['Private-Token'] = this.authToken.token;
        }
      }
    }
    return headers;
  }

  Future<Map<String, dynamic>> mapFromGet(String url,
      {Map<String, dynamic> params,
      bool auth = true,
      Map<String, String> addHeaders}) async {
    var client = http.Client();
    try {
      var headers = this.getHeader(auth: auth, addHeaders: addHeaders);
      var gurl = generateURL(url, params: params);
      var resp = await client.get(gurl, headers: headers);
      print(resp);
      return json.decode(utf8.decode(resp.bodyBytes));
    } catch (e) {
      rethrow;
    }
  }

  Future<List<dynamic>> listFromGet(String url,
      {Map<String, dynamic> params,
      bool auth = true,
      Map<String, String> addHeaders}) async {
    var client = http.Client();
    try {
      var headers = this.getHeader(auth: auth, addHeaders: addHeaders);
      var resp =
          await client.get(generateURL(url, params: params), headers: headers);
      return json.decode(utf8.decode(resp.bodyBytes));
    } catch (e) {
      rethrow;
    }
  }
}
